# -*- coding: utf-8 -*-

__author__ = 'massimo'

import unittest


class UtilTestFunctions(unittest.TestCase):
    def test_verify_url(self):
        self.assertTrue(True)

if __name__ == "__main__":
    UtilTestFunctions.main()
