__author__ = 'massimo'

from setuptools import setup

setup(
    name = "SiteMiner",
    version = "0.1.5",
    author = "massimo",
    author_email = "yangsibai@gmail.com",
    description = "crawl a site and find out all link http status code",
    license = "MIT",
    keywords = "http status site error",
    url = "https://github.com/yangsibai/SiteMiner",
    packages = ['SiteMiner'],
    classifiers = [
        "Development Status :: 3 - Alpha",
        "Topic :: Internet :: WWW/HTTP",
        "License :: OSI Approved :: MIT License"
    ]
)